pub enum IntegratorMethod {
RungeKutta89,
DormandPrince78,
DormandPrince45,
RungeKutta4,
CashKarp45,
Verner56,
}Expand description
Enum of supported integration methods, all of which are part of the Runge Kutta family of ordinary differential equation (ODE) solvers. Nomenclature: X-Y means that this is an X order solver with a Y order error correction step.
Variants
RungeKutta89
Runge Kutta 8-9 is the recommended integrator for most application.
DormandPrince78
Dormand78 is a Dormand-Prince integrator. Coefficients taken from GMAT src/base/propagator/PrinceDormand78.cpp.
DormandPrince45
Dormand45 is a Dormand-Prince integrator.
RungeKutta4
Runge Kutta 4 is a fixed step solver.
CashKarp45
Runge Kutta 4-5 Cash Karp integrator.
Verner56
Verner56 is an RK Verner integrator of order 5-6. Coefficients taken from here (PDF).
Implementations
Sourceimpl IntegratorMethod
impl IntegratorMethod
Sourcepub const fn order(self) -> u8
pub const fn order(self) -> u8
Returns the order of this integrator (as u8 because there probably isn’t an order greater than 255). The order is used for the adaptive step size only to compute the error between estimates.
Sourcepub const fn stages(self) -> usize
pub const fn stages(self) -> usize
Returns the stages of this integrator, i.e. how many times the derivatives will be called
Sourcepub const fn a_coeffs(self) -> &'static [f64]
pub const fn a_coeffs(self) -> &'static [f64]
Returns a pointer to a list of f64 corresponding to the A coefficients of the Butcher table for that RK.
This module only supports implicit integrators, and as such, Self.a_coeffs().len() must be of
size (order+1)*(order)/2.
Warning: this RK trait supposes that the implementation is consistent, i.e. c_i = \sum_j a_{ij}.